<p align="center">
  <img width="100px" alt="ulabox-icon"
    src="docs/icon.png"
  />
</p>
<p align="center">
</p>
<h2 align="center"><code>climoji</code></h2>

## 📜 About
Climoji is an initiative to facilitate the use of the emojis from the command line 🖥.

## ⚒️ Installation
Installation is so easy, you only need to execute
```
pip install climoji
```

## 🚀 Using climoji
Using climoji is as easy as type
```commandline
climoji show :rocket:
```

And a 🚀 will appear 😄


## 🚩 License
The code is available under the MIT license.
